==> hur-1.0.6.tar.gz: hur-1.0.6/setup.py <==
"""
This algorithm proposes a new paradigm in language model architecture, aiming to revolutionize natural language processing through direct weights adjustment and automatic parameter configuration.
The Hur-Model is a development module that implements this concept, enabling the training, retraining, tuning, and inference of language models in a groundbreaking way.
It reduces dependence on backpropagation through an initial weight adjustment using a HurNet network and accelerates model parameterization through optimization calculations and self-configuration.
This code was architected, developed, and programmed by Ben-Hur Varriano for Sapiens Technology®️.
Any use, modification, disclosure, or public commentary without prior authorization from Sapiens Technology®️ will be subject to legal action by our legal team.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
from setuptools import setup, find_packages
package_name = 'hur'
version = '1.0.6'
setup(
    name=package_name,
    version=version,
    author='SAPIENS TECHNOLOGY',
    packages=find_packages(),
    install_requires=[
        'hurnet-torch==1.1.0',
        'sapiens-tokenizer==1.1.5',
        'sapiens-embedding==1.0.9',
        'sapiens-attention==1.0.7',
        'sapiens-infinite-context-window==1.0.5',
        'sapiens-generalization==1.0.1',
        'scn==1.0.9',
        'torch==2.4.1',
        'requests==2.31.0',
        'ijson==3.3.0',
        'tqdm==4.67.1'
    ],
    url='https://github.com/sapiens-technology/Hur-Model',
    license='Proprietary Software'
)
"""
This algorithm proposes a new paradigm in language model architecture, aiming to revolutionize natural language processing through direct weights adjustment and automatic parameter configuration.
The Hur-Model is a development module that implements this concept, enabling the training, retraining, tuning, and inference of language models in a groundbreaking way.
It reduces dependence on backpropagation through an initial weight adjustment using a HurNet network and accelerates model parameterization through optimization calculations and self-configuration.
This code was architected, developed, and programmed by Ben-Hur Varriano for Sapiens Technology®️.
Any use, modification, disclosure, or public commentary without prior authorization from Sapiens Technology®️ will be subject to legal action by our legal team.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------

==> hur-1.0.7.tar.gz: hur-1.0.7/setup.py <==
"""
This algorithm proposes a new paradigm in language model architecture, aiming to revolutionize natural language processing through direct weights adjustment and automatic parameter configuration.
The Hur-Model is a development module that implements this concept, enabling the training, retraining, tuning, and inference of language models in a groundbreaking way.
It reduces dependence on backpropagation through an initial weight adjustment using a HurNet network and accelerates model parameterization through optimization calculations and self-configuration.
This code was architected, developed, and programmed by Ben-Hur Varriano for Sapiens Technology®️.
Any use, modification, disclosure, or public commentary without prior authorization from Sapiens Technology®️ will be subject to legal action by our legal team.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
from setuptools import setup, find_packages
package_name = 'hur'
version = '1.0.7'
setup(
    name=package_name,
    version=version,
    author='SAPIENS TECHNOLOGY',
    packages=find_packages(),
    install_requires=[
        'hurnet-torch',
        'sapiens-tokenizer',
        'sapiens-embedding',
        'sapiens-attention',
        'sapiens-infinite-context-window',
        'sapiens-generalization',
        'scn',
        'torch',
        'requests',
        'ijson',
        'tqdm'
    ],
    url='https://github.com/sapiens-technology/Hur-Model',
    license='Proprietary Software'
)
"""
This algorithm proposes a new paradigm in language model architecture, aiming to revolutionize natural language processing through direct weights adjustment and automatic parameter configuration.
The Hur-Model is a development module that implements this concept, enabling the training, retraining, tuning, and inference of language models in a groundbreaking way.
It reduces dependence on backpropagation through an initial weight adjustment using a HurNet network and accelerates model parameterization through optimization calculations and self-configuration.
This code was architected, developed, and programmed by Ben-Hur Varriano for Sapiens Technology®️.
Any use, modification, disclosure, or public commentary without prior authorization from Sapiens Technology®️ will be subject to legal action by our legal team.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
